@@ -383,7 +383,7 @@ def parse_cmdline_options(arglist):
     # --archive-dir <path>
     parser.add_option("--file-to-restore", "-r", action="callback", type="file",
                       metavar=_("path"), dest="restore_dir",
-                      callback=lambda o, s, v, p: setattr(p.values, "restore_dir", v.rstrip('/')))
+                      callback=lambda o, s, v, p: setattr(p.values, "restore_dir", v.strip('/')))
 
     # Used to confirm certain destructive operations like deleting old files.
     parser.add_option("--force", action="store_true")
@@ -623,11 +623,6 @@ def parse_cmdline_options(arglist):
     parser.add_option("--volsize", type="int", action="callback", metavar=_("number"),
                       callback=lambda o, s, v, p: setattr(p.values, "volsize", v * 1024 * 1024))
 
-    # If set, collect only the file status, not the whole root.
-    parser.add_option("--file-changed", action="callback", type="file",
-                      metavar=_("path"), dest="file_changed",
-                      callback=lambda o, s, v, p: setattr(p.values, "file_changed", v.rstrip('/')))
-
     # delay time before next try after a failure of a backend operation
     # TRANSL: Used in usage help. Example:
     # --backend-retry-delay <seconds>
